==> ember-do-forms-1.8.2.tgz: package/CHANGELOG.md <==
# Change Log

## [v1.8.2](https://github.com/shuriu/ember-do-forms/tree/v1.8.2) (2017-05-18)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.8.1...v1.8.2)

**Closed issues:**

- Issue with checkbox [\#20](https://github.com/shuriu/ember-do-forms/issues/20)
- An in-range update of ember-cli-htmlbars is breaking the build 🚨 [\#17](https://github.com/shuriu/ember-do-forms/issues/17)

**Merged pull requests:**

- fix\(package\): update ember-cli-htmlbars to version 2.0.1 [\#22](https://github.com/shuriu/ember-do-forms/pull/22) ([shuriu](https://github.com/shuriu))
- Update ember-cli-dependency-checker to the latest version 🚀 [\#21](https://github.com/shuriu/ember-do-forms/pull/21) ([greenkeeper[bot]](https://github.com/integration/greenkeeper))
- Update ember-cli to the latest version 🚀 [\#16](https://github.com/shuriu/ember-do-forms/pull/16) ([greenkeeper[bot]](https://github.com/integration/greenkeeper))

## [v1.8.1](https://github.com/shuriu/ember-do-forms/tree/v1.8.1) (2017-05-01)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.8.0...v1.8.1)

**Merged pull requests:**

- chore\(package\): update ember-cli to version 2.13.0 [\#15](https://github.com/shuriu/ember-do-forms/pull/15) ([shuriu](https://github.com/shuriu))

## [v1.8.0](https://github.com/shuriu/ember-do-forms/tree/v1.8.0) (2017-04-27)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.7.1...v1.8.0)

**Implemented enhancements:**

- Add a do-fields component [\#9](https://github.com/shuriu/ember-do-forms/issues/9)
- Allow autogeneration of data-test-\* attributes [\#8](https://github.com/shuriu/ember-do-forms/issues/8)

**Fixed bugs:**

- do-control is missing some attributes  [\#7](https://github.com/shuriu/ember-do-forms/issues/7)

**Merged pull requests:**

- Add support for textarea rows [\#6](https://github.com/shuriu/ember-do-forms/pull/6) ([kevintraver](https://github.com/kevintraver))

## [v1.7.1](https://github.com/shuriu/ember-do-forms/tree/v1.7.1) (2017-04-24)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.7.0...v1.7.1)

**Merged pull requests:**

- Update ember-cli to the latest version 🚀 [\#4](https://github.com/shuriu/ember-do-forms/pull/4) ([greenkeeper[bot]](https://github.com/integration/greenkeeper))

## [v1.7.0](https://github.com/shuriu/ember-do-forms/tree/v1.7.0) (2017-04-21)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.6.0...v1.7.0)

## [v1.6.0](https://github.com/shuriu/ember-do-forms/tree/v1.6.0) (2017-04-21)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.5.4...v1.6.0)

**Merged pull requests:**

- Add Greenkeeper badge 🌴 [\#1](https://github.com/shuriu/ember-do-forms/pull/1) ([greenkeeper[bot]](https://github.com/integration/greenkeeper))

## [v1.5.4](https://github.com/shuriu/ember-do-forms/tree/v1.5.4) (2017-04-20)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.5.3...v1.5.4)

## [v1.5.3](https://github.com/shuriu/ember-do-forms/tree/v1.5.3) (2017-04-19)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.5.2...v1.5.3)

## [v1.5.2](https://github.com/shuriu/ember-do-forms/tree/v1.5.2) (2017-04-10)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.5.1...v1.5.2)

## [v1.5.1](https://github.com/shuriu/ember-do-forms/tree/v1.5.1) (2017-04-10)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.5.0...v1.5.1)

## [v1.5.0](https://github.com/shuriu/ember-do-forms/tree/v1.5.0) (2017-04-10)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.4.0...v1.5.0)

## [v1.4.0](https://github.com/shuriu/ember-do-forms/tree/v1.4.0) (2017-04-04)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.3.0...v1.4.0)

## [v1.3.0](https://github.com/shuriu/ember-do-forms/tree/v1.3.0) (2017-03-30)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.2.0...v1.3.0)

## [v1.2.0](https://github.com/shuriu/ember-do-forms/tree/v1.2.0) (2017-03-30)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.1.0...v1.2.0)

## [v1.1.0](https://github.com/shuriu/ember-do-forms/tree/v1.1.0) (2017-03-29)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.0.2...v1.1.0)

## [v1.0.2](https://github.com/shuriu/ember-do-forms/tree/v1.0.2) (2017-03-28)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.0.1...v1.0.2)

## [v1.0.1](https://github.com/shuriu/ember-do-forms/tree/v1.0.1) (2017-03-28)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/1.0.0...v1.0.1)

## [1.0.0](https://github.com/shuriu/ember-do-forms/tree/1.0.0) (2017-03-28)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> ember-do-forms-1.9.0.tgz: package/CHANGELOG.md <==
# Change Log

## [v1.9.0](https://github.com/shuriu/ember-do-forms/tree/v1.9.0) (2017-05-23)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.8.2...v1.9.0)

**Closed issues:**

- An in-range update of ember-cp-validations is breaking the build 🚨 [\#19](https://github.com/shuriu/ember-do-forms/issues/19)

**Merged pull requests:**

- Update ember-cli to the latest version 🚀 [\#23](https://github.com/shuriu/ember-do-forms/pull/23) ([greenkeeper[bot]](https://github.com/app/greenkeeper))

## [v1.8.2](https://github.com/shuriu/ember-do-forms/tree/v1.8.2) (2017-05-18)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.8.1...v1.8.2)

**Closed issues:**

- Issue with checkbox [\#20](https://github.com/shuriu/ember-do-forms/issues/20)
- An in-range update of ember-cli-htmlbars is breaking the build 🚨 [\#17](https://github.com/shuriu/ember-do-forms/issues/17)

**Merged pull requests:**

- fix\(package\): update ember-cli-htmlbars to version 2.0.1 [\#22](https://github.com/shuriu/ember-do-forms/pull/22) ([shuriu](https://github.com/shuriu))
- Update ember-cli-dependency-checker to the latest version 🚀 [\#21](https://github.com/shuriu/ember-do-forms/pull/21) ([greenkeeper[bot]](https://github.com/app/greenkeeper))
- Update ember-cli to the latest version 🚀 [\#16](https://github.com/shuriu/ember-do-forms/pull/16) ([greenkeeper[bot]](https://github.com/app/greenkeeper))

## [v1.8.1](https://github.com/shuriu/ember-do-forms/tree/v1.8.1) (2017-05-01)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.8.0...v1.8.1)

**Merged pull requests:**

- chore\(package\): update ember-cli to version 2.13.0 [\#15](https://github.com/shuriu/ember-do-forms/pull/15) ([shuriu](https://github.com/shuriu))

## [v1.8.0](https://github.com/shuriu/ember-do-forms/tree/v1.8.0) (2017-04-27)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.7.1...v1.8.0)

**Implemented enhancements:**

- Add a do-fields component [\#9](https://github.com/shuriu/ember-do-forms/issues/9)
- Allow autogeneration of data-test-\* attributes [\#8](https://github.com/shuriu/ember-do-forms/issues/8)

**Fixed bugs:**

- do-control is missing some attributes  [\#7](https://github.com/shuriu/ember-do-forms/issues/7)

**Merged pull requests:**

- Add support for textarea rows [\#6](https://github.com/shuriu/ember-do-forms/pull/6) ([kevintraver](https://github.com/kevintraver))

## [v1.7.1](https://github.com/shuriu/ember-do-forms/tree/v1.7.1) (2017-04-24)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.7.0...v1.7.1)

**Merged pull requests:**

- Update ember-cli to the latest version 🚀 [\#4](https://github.com/shuriu/ember-do-forms/pull/4) ([greenkeeper[bot]](https://github.com/app/greenkeeper))

## [v1.7.0](https://github.com/shuriu/ember-do-forms/tree/v1.7.0) (2017-04-21)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.6.0...v1.7.0)

## [v1.6.0](https://github.com/shuriu/ember-do-forms/tree/v1.6.0) (2017-04-21)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.5.4...v1.6.0)

**Merged pull requests:**

- Add Greenkeeper badge 🌴 [\#1](https://github.com/shuriu/ember-do-forms/pull/1) ([greenkeeper[bot]](https://github.com/app/greenkeeper))

## [v1.5.4](https://github.com/shuriu/ember-do-forms/tree/v1.5.4) (2017-04-20)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.5.3...v1.5.4)

## [v1.5.3](https://github.com/shuriu/ember-do-forms/tree/v1.5.3) (2017-04-19)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.5.2...v1.5.3)

## [v1.5.2](https://github.com/shuriu/ember-do-forms/tree/v1.5.2) (2017-04-10)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.5.1...v1.5.2)

## [v1.5.1](https://github.com/shuriu/ember-do-forms/tree/v1.5.1) (2017-04-10)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.5.0...v1.5.1)

## [v1.5.0](https://github.com/shuriu/ember-do-forms/tree/v1.5.0) (2017-04-10)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.4.0...v1.5.0)

## [v1.4.0](https://github.com/shuriu/ember-do-forms/tree/v1.4.0) (2017-04-04)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.3.0...v1.4.0)

## [v1.3.0](https://github.com/shuriu/ember-do-forms/tree/v1.3.0) (2017-03-30)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.2.0...v1.3.0)

## [v1.2.0](https://github.com/shuriu/ember-do-forms/tree/v1.2.0) (2017-03-30)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.1.0...v1.2.0)

## [v1.1.0](https://github.com/shuriu/ember-do-forms/tree/v1.1.0) (2017-03-29)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.0.2...v1.1.0)

## [v1.0.2](https://github.com/shuriu/ember-do-forms/tree/v1.0.2) (2017-03-28)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/v1.0.1...v1.0.2)

## [v1.0.1](https://github.com/shuriu/ember-do-forms/tree/v1.0.1) (2017-03-28)
[Full Changelog](https://github.com/shuriu/ember-do-forms/compare/1.0.0...v1.0.1)

## [1.0.0](https://github.com/shuriu/ember-do-forms/tree/1.0.0) (2017-03-28)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*
